# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/sqlqueryrun/v1/sqlqueryrun.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='github.com/metaprov/modelaapi/services/sqlqueryrun/v1/sqlqueryrun.proto',
  package='github.com.metaprov.modelaapi.services.sqlqueryrun.v1',
  syntax='proto3',
  serialized_options=b'Z5github.com/metaprov/modelaapi/services/sqlqueryrun/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nGgithub.com/metaprov/modelaapi/services/sqlqueryrun/v1/sqlqueryrun.proto\x12\x35github.com.metaprov.modelaapi.services.sqlqueryrun.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x44github.com/metaprov/modelaapi/pkg/apis/data/v1alpha1/generated.proto\"\xd5\x01\n\x17ListSqlQueryRunsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12j\n\x06labels\x18\x03 \x03(\x0b\x32Z.github.com.metaprov.modelaapi.services.sqlqueryrun.v1.ListSqlQueryRunsRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"p\n\x18ListSqlQueryRunsResponse\x12T\n\x05items\x18\x01 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.SqlQueryRunList\"\x1b\n\x19\x43reateSqlQueryRunResponse\"k\n\x18\x43reateSqlQueryRunRequest\x12O\n\x04item\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.SqlQueryRun\"k\n\x18UpdateSqlQueryRunRequest\x12O\n\x04item\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.SqlQueryRun\"\x1b\n\x19UpdateSqlQueryRunResponse\"8\n\x15GetSqlQueryRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"w\n\x16GetSqlQueryRunResponse\x12O\n\x04item\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.SqlQueryRun\x12\x0c\n\x04yaml\x18\x02 \x01(\t\";\n\x18\x44\x65leteSqlQueryRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x1b\n\x19\x44\x65leteSqlQueryRunResponse\"h\n\x15RunSqlQueryRunRequest\x12O\n\x04item\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.SqlQueryRun\"\x18\n\x16RunSqlQueryRunResponse2\xac\n\n\x12SqlQueryRunService\x12\xce\x01\n\x11ListSqlQuerieRuns\x12N.github.com.metaprov.modelaapi.services.sqlqueryrun.v1.ListSqlQueryRunsRequest\x1aO.github.com.metaprov.modelaapi.services.sqlqueryrun.v1.ListSqlQueryRunsResponse\"\x18\x82\xd3\xe4\x93\x02\x12\x12\x10/v1/sqlqueryruns\x12\xd3\x01\n\x11\x43reateSqlQueryRun\x12O.github.com.metaprov.modelaapi.services.sqlqueryrun.v1.CreateSqlQueryRunRequest\x1aP.github.com.metaprov.modelaapi.services.sqlqueryrun.v1.CreateSqlQueryRunResponse\"\x1b\x82\xd3\xe4\x93\x02\x15\"\x10/v1/sqlqueryruns:\x01*\x12\xce\x01\n\x0eGetSqlQueryRun\x12L.github.com.metaprov.modelaapi.services.sqlqueryrun.v1.GetSqlQueryRunRequest\x1aM.github.com.metaprov.modelaapi.services.sqlqueryrun.v1.GetSqlQueryRunResponse\"\x1f\x82\xd3\xe4\x93\x02\x19\x12\x17/v1/sqlqueryruns/{name}\x12\xee\x01\n\x11UpdateSqlQueryRun\x12O.github.com.metaprov.modelaapi.services.sqlqueryrun.v1.UpdateSqlQueryRunRequest\x1aP.github.com.metaprov.modelaapi.services.sqlqueryrun.v1.UpdateSqlQueryRunResponse\"6\x82\xd3\xe4\x93\x02\x30\x1a+/v1/sqlqueryruns/{webrequest.metadata.name}:\x01*\x12\xd7\x01\n\x11\x44\x65leteSqlQueryRun\x12O.github.com.metaprov.modelaapi.services.sqlqueryrun.v1.DeleteSqlQueryRunRequest\x1aP.github.com.metaprov.modelaapi.services.sqlqueryrun.v1.DeleteSqlQueryRunResponse\"\x1f\x82\xd3\xe4\x93\x02\x19*\x17/v1/sqlqueryruns/{name}\x12\xd2\x01\n\x0eRunSqlQueryRun\x12L.github.com.metaprov.modelaapi.services.sqlqueryrun.v1.RunSqlQueryRunRequest\x1aM.github.com.metaprov.modelaapi.services.sqlqueryrun.v1.RunSqlQueryRunResponse\"#\x82\xd3\xe4\x93\x02\x1d\"\x1b/v1/sqlqueryruns/{name}:runB7Z5github.com/metaprov/modelaapi/services/sqlqueryrun/v1b\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2.DESCRIPTOR,])




_LISTSQLQUERYRUNSREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='github.com.metaprov.modelaapi.services.sqlqueryrun.v1.ListSqlQueryRunsRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.sqlqueryrun.v1.ListSqlQueryRunsRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.sqlqueryrun.v1.ListSqlQueryRunsRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=399,
  serialized_end=444,
)

_LISTSQLQUERYRUNSREQUEST = _descriptor.Descriptor(
  name='ListSqlQueryRunsRequest',
  full_name='github.com.metaprov.modelaapi.services.sqlqueryrun.v1.ListSqlQueryRunsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.sqlqueryrun.v1.ListSqlQueryRunsRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.sqlqueryrun.v1.ListSqlQueryRunsRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='github.com.metaprov.modelaapi.services.sqlqueryrun.v1.ListSqlQueryRunsRequest.labels', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTSQLQUERYRUNSREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=231,
  serialized_end=444,
)


_LISTSQLQUERYRUNSRESPONSE = _descriptor.Descriptor(
  name='ListSqlQueryRunsResponse',
  full_name='github.com.metaprov.modelaapi.services.sqlqueryrun.v1.ListSqlQueryRunsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.sqlqueryrun.v1.ListSqlQueryRunsResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=446,
  serialized_end=558,
)


_CREATESQLQUERYRUNRESPONSE = _descriptor.Descriptor(
  name='CreateSqlQueryRunResponse',
  full_name='github.com.metaprov.modelaapi.services.sqlqueryrun.v1.CreateSqlQueryRunResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=560,
  serialized_end=587,
)


_CREATESQLQUERYRUNREQUEST = _descriptor.Descriptor(
  name='CreateSqlQueryRunRequest',
  full_name='github.com.metaprov.modelaapi.services.sqlqueryrun.v1.CreateSqlQueryRunRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.sqlqueryrun.v1.CreateSqlQueryRunRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=589,
  serialized_end=696,
)


_UPDATESQLQUERYRUNREQUEST = _descriptor.Descriptor(
  name='UpdateSqlQueryRunRequest',
  full_name='github.com.metaprov.modelaapi.services.sqlqueryrun.v1.UpdateSqlQueryRunRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.sqlqueryrun.v1.UpdateSqlQueryRunRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=698,
  serialized_end=805,
)


_UPDATESQLQUERYRUNRESPONSE = _descriptor.Descriptor(
  name='UpdateSqlQueryRunResponse',
  full_name='github.com.metaprov.modelaapi.services.sqlqueryrun.v1.UpdateSqlQueryRunResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=807,
  serialized_end=834,
)


_GETSQLQUERYRUNREQUEST = _descriptor.Descriptor(
  name='GetSqlQueryRunRequest',
  full_name='github.com.metaprov.modelaapi.services.sqlqueryrun.v1.GetSqlQueryRunRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.sqlqueryrun.v1.GetSqlQueryRunRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.sqlqueryrun.v1.GetSqlQueryRunRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=836,
  serialized_end=892,
)


_GETSQLQUERYRUNRESPONSE = _descriptor.Descriptor(
  name='GetSqlQueryRunResponse',
  full_name='github.com.metaprov.modelaapi.services.sqlqueryrun.v1.GetSqlQueryRunResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.sqlqueryrun.v1.GetSqlQueryRunResponse.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yaml', full_name='github.com.metaprov.modelaapi.services.sqlqueryrun.v1.GetSqlQueryRunResponse.yaml', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=894,
  serialized_end=1013,
)


_DELETESQLQUERYRUNREQUEST = _descriptor.Descriptor(
  name='DeleteSqlQueryRunRequest',
  full_name='github.com.metaprov.modelaapi.services.sqlqueryrun.v1.DeleteSqlQueryRunRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.sqlqueryrun.v1.DeleteSqlQueryRunRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.sqlqueryrun.v1.DeleteSqlQueryRunRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1015,
  serialized_end=1074,
)


_DELETESQLQUERYRUNRESPONSE = _descriptor.Descriptor(
  name='DeleteSqlQueryRunResponse',
  full_name='github.com.metaprov.modelaapi.services.sqlqueryrun.v1.DeleteSqlQueryRunResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1076,
  serialized_end=1103,
)


_RUNSQLQUERYRUNREQUEST = _descriptor.Descriptor(
  name='RunSqlQueryRunRequest',
  full_name='github.com.metaprov.modelaapi.services.sqlqueryrun.v1.RunSqlQueryRunRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.sqlqueryrun.v1.RunSqlQueryRunRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1105,
  serialized_end=1209,
)


_RUNSQLQUERYRUNRESPONSE = _descriptor.Descriptor(
  name='RunSqlQueryRunResponse',
  full_name='github.com.metaprov.modelaapi.services.sqlqueryrun.v1.RunSqlQueryRunResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1211,
  serialized_end=1235,
)

_LISTSQLQUERYRUNSREQUEST_LABELSENTRY.containing_type = _LISTSQLQUERYRUNSREQUEST
_LISTSQLQUERYRUNSREQUEST.fields_by_name['labels'].message_type = _LISTSQLQUERYRUNSREQUEST_LABELSENTRY
_LISTSQLQUERYRUNSRESPONSE.fields_by_name['items'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._SQLQUERYRUNLIST
_CREATESQLQUERYRUNREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._SQLQUERYRUN
_UPDATESQLQUERYRUNREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._SQLQUERYRUN
_GETSQLQUERYRUNRESPONSE.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._SQLQUERYRUN
_RUNSQLQUERYRUNREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._SQLQUERYRUN
DESCRIPTOR.message_types_by_name['ListSqlQueryRunsRequest'] = _LISTSQLQUERYRUNSREQUEST
DESCRIPTOR.message_types_by_name['ListSqlQueryRunsResponse'] = _LISTSQLQUERYRUNSRESPONSE
DESCRIPTOR.message_types_by_name['CreateSqlQueryRunResponse'] = _CREATESQLQUERYRUNRESPONSE
DESCRIPTOR.message_types_by_name['CreateSqlQueryRunRequest'] = _CREATESQLQUERYRUNREQUEST
DESCRIPTOR.message_types_by_name['UpdateSqlQueryRunRequest'] = _UPDATESQLQUERYRUNREQUEST
DESCRIPTOR.message_types_by_name['UpdateSqlQueryRunResponse'] = _UPDATESQLQUERYRUNRESPONSE
DESCRIPTOR.message_types_by_name['GetSqlQueryRunRequest'] = _GETSQLQUERYRUNREQUEST
DESCRIPTOR.message_types_by_name['GetSqlQueryRunResponse'] = _GETSQLQUERYRUNRESPONSE
DESCRIPTOR.message_types_by_name['DeleteSqlQueryRunRequest'] = _DELETESQLQUERYRUNREQUEST
DESCRIPTOR.message_types_by_name['DeleteSqlQueryRunResponse'] = _DELETESQLQUERYRUNRESPONSE
DESCRIPTOR.message_types_by_name['RunSqlQueryRunRequest'] = _RUNSQLQUERYRUNREQUEST
DESCRIPTOR.message_types_by_name['RunSqlQueryRunResponse'] = _RUNSQLQUERYRUNRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ListSqlQueryRunsRequest = _reflection.GeneratedProtocolMessageType('ListSqlQueryRunsRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTSQLQUERYRUNSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.sqlqueryrun.v1.sqlqueryrun_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.sqlqueryrun.v1.ListSqlQueryRunsRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTSQLQUERYRUNSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.sqlqueryrun.v1.sqlqueryrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.sqlqueryrun.v1.ListSqlQueryRunsRequest)
  })
_sym_db.RegisterMessage(ListSqlQueryRunsRequest)
_sym_db.RegisterMessage(ListSqlQueryRunsRequest.LabelsEntry)

ListSqlQueryRunsResponse = _reflection.GeneratedProtocolMessageType('ListSqlQueryRunsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTSQLQUERYRUNSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.sqlqueryrun.v1.sqlqueryrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.sqlqueryrun.v1.ListSqlQueryRunsResponse)
  })
_sym_db.RegisterMessage(ListSqlQueryRunsResponse)

CreateSqlQueryRunResponse = _reflection.GeneratedProtocolMessageType('CreateSqlQueryRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATESQLQUERYRUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.sqlqueryrun.v1.sqlqueryrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.sqlqueryrun.v1.CreateSqlQueryRunResponse)
  })
_sym_db.RegisterMessage(CreateSqlQueryRunResponse)

CreateSqlQueryRunRequest = _reflection.GeneratedProtocolMessageType('CreateSqlQueryRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATESQLQUERYRUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.sqlqueryrun.v1.sqlqueryrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.sqlqueryrun.v1.CreateSqlQueryRunRequest)
  })
_sym_db.RegisterMessage(CreateSqlQueryRunRequest)

UpdateSqlQueryRunRequest = _reflection.GeneratedProtocolMessageType('UpdateSqlQueryRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATESQLQUERYRUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.sqlqueryrun.v1.sqlqueryrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.sqlqueryrun.v1.UpdateSqlQueryRunRequest)
  })
_sym_db.RegisterMessage(UpdateSqlQueryRunRequest)

UpdateSqlQueryRunResponse = _reflection.GeneratedProtocolMessageType('UpdateSqlQueryRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATESQLQUERYRUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.sqlqueryrun.v1.sqlqueryrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.sqlqueryrun.v1.UpdateSqlQueryRunResponse)
  })
_sym_db.RegisterMessage(UpdateSqlQueryRunResponse)

GetSqlQueryRunRequest = _reflection.GeneratedProtocolMessageType('GetSqlQueryRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSQLQUERYRUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.sqlqueryrun.v1.sqlqueryrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.sqlqueryrun.v1.GetSqlQueryRunRequest)
  })
_sym_db.RegisterMessage(GetSqlQueryRunRequest)

GetSqlQueryRunResponse = _reflection.GeneratedProtocolMessageType('GetSqlQueryRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETSQLQUERYRUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.sqlqueryrun.v1.sqlqueryrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.sqlqueryrun.v1.GetSqlQueryRunResponse)
  })
_sym_db.RegisterMessage(GetSqlQueryRunResponse)

DeleteSqlQueryRunRequest = _reflection.GeneratedProtocolMessageType('DeleteSqlQueryRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETESQLQUERYRUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.sqlqueryrun.v1.sqlqueryrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.sqlqueryrun.v1.DeleteSqlQueryRunRequest)
  })
_sym_db.RegisterMessage(DeleteSqlQueryRunRequest)

DeleteSqlQueryRunResponse = _reflection.GeneratedProtocolMessageType('DeleteSqlQueryRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETESQLQUERYRUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.sqlqueryrun.v1.sqlqueryrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.sqlqueryrun.v1.DeleteSqlQueryRunResponse)
  })
_sym_db.RegisterMessage(DeleteSqlQueryRunResponse)

RunSqlQueryRunRequest = _reflection.GeneratedProtocolMessageType('RunSqlQueryRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _RUNSQLQUERYRUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.sqlqueryrun.v1.sqlqueryrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.sqlqueryrun.v1.RunSqlQueryRunRequest)
  })
_sym_db.RegisterMessage(RunSqlQueryRunRequest)

RunSqlQueryRunResponse = _reflection.GeneratedProtocolMessageType('RunSqlQueryRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _RUNSQLQUERYRUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.sqlqueryrun.v1.sqlqueryrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.sqlqueryrun.v1.RunSqlQueryRunResponse)
  })
_sym_db.RegisterMessage(RunSqlQueryRunResponse)


DESCRIPTOR._options = None
_LISTSQLQUERYRUNSREQUEST_LABELSENTRY._options = None

_SQLQUERYRUNSERVICE = _descriptor.ServiceDescriptor(
  name='SqlQueryRunService',
  full_name='github.com.metaprov.modelaapi.services.sqlqueryrun.v1.SqlQueryRunService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1238,
  serialized_end=2562,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListSqlQuerieRuns',
    full_name='github.com.metaprov.modelaapi.services.sqlqueryrun.v1.SqlQueryRunService.ListSqlQuerieRuns',
    index=0,
    containing_service=None,
    input_type=_LISTSQLQUERYRUNSREQUEST,
    output_type=_LISTSQLQUERYRUNSRESPONSE,
    serialized_options=b'\202\323\344\223\002\022\022\020/v1/sqlqueryruns',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateSqlQueryRun',
    full_name='github.com.metaprov.modelaapi.services.sqlqueryrun.v1.SqlQueryRunService.CreateSqlQueryRun',
    index=1,
    containing_service=None,
    input_type=_CREATESQLQUERYRUNREQUEST,
    output_type=_CREATESQLQUERYRUNRESPONSE,
    serialized_options=b'\202\323\344\223\002\025\"\020/v1/sqlqueryruns:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetSqlQueryRun',
    full_name='github.com.metaprov.modelaapi.services.sqlqueryrun.v1.SqlQueryRunService.GetSqlQueryRun',
    index=2,
    containing_service=None,
    input_type=_GETSQLQUERYRUNREQUEST,
    output_type=_GETSQLQUERYRUNRESPONSE,
    serialized_options=b'\202\323\344\223\002\031\022\027/v1/sqlqueryruns/{name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateSqlQueryRun',
    full_name='github.com.metaprov.modelaapi.services.sqlqueryrun.v1.SqlQueryRunService.UpdateSqlQueryRun',
    index=3,
    containing_service=None,
    input_type=_UPDATESQLQUERYRUNREQUEST,
    output_type=_UPDATESQLQUERYRUNRESPONSE,
    serialized_options=b'\202\323\344\223\0020\032+/v1/sqlqueryruns/{webrequest.metadata.name}:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteSqlQueryRun',
    full_name='github.com.metaprov.modelaapi.services.sqlqueryrun.v1.SqlQueryRunService.DeleteSqlQueryRun',
    index=4,
    containing_service=None,
    input_type=_DELETESQLQUERYRUNREQUEST,
    output_type=_DELETESQLQUERYRUNRESPONSE,
    serialized_options=b'\202\323\344\223\002\031*\027/v1/sqlqueryruns/{name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RunSqlQueryRun',
    full_name='github.com.metaprov.modelaapi.services.sqlqueryrun.v1.SqlQueryRunService.RunSqlQueryRun',
    index=5,
    containing_service=None,
    input_type=_RUNSQLQUERYRUNREQUEST,
    output_type=_RUNSQLQUERYRUNRESPONSE,
    serialized_options=b'\202\323\344\223\002\035\"\033/v1/sqlqueryruns/{name}:run',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_SQLQUERYRUNSERVICE)

DESCRIPTOR.services_by_name['SqlQueryRunService'] = _SQLQUERYRUNSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/webrequest/v1/webrequest.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='github.com/metaprov/modelaapi/services/webrequest/v1/webrequest.proto',
  package='github.com.metaprov.modelaapi.services.webrequest.v1',
  syntax='proto3',
  serialized_options=b'Z4github.com/metaprov/modelaapi/services/webrequest/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nEgithub.com/metaprov/modelaapi/services/webrequest/v1/webrequest.proto\x12\x34github.com.metaprov.modelaapi.services.webrequest.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x44github.com/metaprov/modelaapi/pkg/apis/data/v1alpha1/generated.proto\"\xd2\x01\n\x16ListWebRequestsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12h\n\x06labels\x18\x03 \x03(\x0b\x32X.github.com.metaprov.modelaapi.services.webrequest.v1.ListWebRequestsRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"n\n\x17ListWebRequestsResponse\x12S\n\x05items\x18\x01 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.WebRequestList\"\x1a\n\x18\x43reateWebRequestResponse\"i\n\x17\x43reateWebRequestRequest\x12N\n\x04item\x18\x01 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.WebRequest\"i\n\x17UpdateWebRequestRequest\x12N\n\x04item\x18\x01 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.WebRequest\"\x1a\n\x18UpdateWebRequestResponse\"7\n\x14GetWebRequestRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"u\n\x15GetWebRequestResponse\x12N\n\x04item\x18\x01 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.WebRequest\x12\x0c\n\x04yaml\x18\x02 \x01(\t\":\n\x17\x44\x65leteWebRequestRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x1a\n\x18\x44\x65leteWebRequestResponse\"f\n\x14RunWebRequestRequest\x12N\n\x04item\x18\x01 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.WebRequest\"\x17\n\x15RunWebRequestResponse2\x86\n\n\x11WebRequestService\x12\xc7\x01\n\x0fListWebRequests\x12L.github.com.metaprov.modelaapi.services.webrequest.v1.ListWebRequestsRequest\x1aM.github.com.metaprov.modelaapi.services.webrequest.v1.ListWebRequestsResponse\"\x17\x82\xd3\xe4\x93\x02\x11\x12\x0f/v1/webrequests\x12\xcd\x01\n\x10\x43reateWebRequest\x12M.github.com.metaprov.modelaapi.services.webrequest.v1.CreateWebRequestRequest\x1aN.github.com.metaprov.modelaapi.services.webrequest.v1.CreateWebRequestResponse\"\x1a\x82\xd3\xe4\x93\x02\x14\"\x0f/v1/webrequests:\x01*\x12\xc8\x01\n\rGetWebRequest\x12J.github.com.metaprov.modelaapi.services.webrequest.v1.GetWebRequestRequest\x1aK.github.com.metaprov.modelaapi.services.webrequest.v1.GetWebRequestResponse\"\x1e\x82\xd3\xe4\x93\x02\x18\x12\x16/v1/webrequests/{name}\x12\xe8\x01\n\x10UpdateWebRequest\x12M.github.com.metaprov.modelaapi.services.webrequest.v1.UpdateWebRequestRequest\x1aN.github.com.metaprov.modelaapi.services.webrequest.v1.UpdateWebRequestResponse\"5\x82\xd3\xe4\x93\x02/\x1a*/v1/webrequests/{prediction.metadata.name}:\x01*\x12\xd1\x01\n\x10\x44\x65leteWebRequest\x12M.github.com.metaprov.modelaapi.services.webrequest.v1.DeleteWebRequestRequest\x1aN.github.com.metaprov.modelaapi.services.webrequest.v1.DeleteWebRequestResponse\"\x1e\x82\xd3\xe4\x93\x02\x18*\x16/v1/webrequests/{name}\x12\xcc\x01\n\rRunWebRequest\x12J.github.com.metaprov.modelaapi.services.webrequest.v1.RunWebRequestRequest\x1aK.github.com.metaprov.modelaapi.services.webrequest.v1.RunWebRequestResponse\"\"\x82\xd3\xe4\x93\x02\x1c\"\x1a/v1/webrequests/{name}:runB6Z4github.com/metaprov/modelaapi/services/webrequest/v1b\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2.DESCRIPTOR,])




_LISTWEBREQUESTSREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='github.com.metaprov.modelaapi.services.webrequest.v1.ListWebRequestsRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.webrequest.v1.ListWebRequestsRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.webrequest.v1.ListWebRequestsRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=393,
  serialized_end=438,
)

_LISTWEBREQUESTSREQUEST = _descriptor.Descriptor(
  name='ListWebRequestsRequest',
  full_name='github.com.metaprov.modelaapi.services.webrequest.v1.ListWebRequestsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.webrequest.v1.ListWebRequestsRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.webrequest.v1.ListWebRequestsRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='github.com.metaprov.modelaapi.services.webrequest.v1.ListWebRequestsRequest.labels', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTWEBREQUESTSREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=228,
  serialized_end=438,
)


_LISTWEBREQUESTSRESPONSE = _descriptor.Descriptor(
  name='ListWebRequestsResponse',
  full_name='github.com.metaprov.modelaapi.services.webrequest.v1.ListWebRequestsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.webrequest.v1.ListWebRequestsResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=440,
  serialized_end=550,
)


_CREATEWEBREQUESTRESPONSE = _descriptor.Descriptor(
  name='CreateWebRequestResponse',
  full_name='github.com.metaprov.modelaapi.services.webrequest.v1.CreateWebRequestResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=552,
  serialized_end=578,
)


_CREATEWEBREQUESTREQUEST = _descriptor.Descriptor(
  name='CreateWebRequestRequest',
  full_name='github.com.metaprov.modelaapi.services.webrequest.v1.CreateWebRequestRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.webrequest.v1.CreateWebRequestRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=580,
  serialized_end=685,
)


_UPDATEWEBREQUESTREQUEST = _descriptor.Descriptor(
  name='UpdateWebRequestRequest',
  full_name='github.com.metaprov.modelaapi.services.webrequest.v1.UpdateWebRequestRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.webrequest.v1.UpdateWebRequestRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=687,
  serialized_end=792,
)


_UPDATEWEBREQUESTRESPONSE = _descriptor.Descriptor(
  name='UpdateWebRequestResponse',
  full_name='github.com.metaprov.modelaapi.services.webrequest.v1.UpdateWebRequestResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=794,
  serialized_end=820,
)


_GETWEBREQUESTREQUEST = _descriptor.Descriptor(
  name='GetWebRequestRequest',
  full_name='github.com.metaprov.modelaapi.services.webrequest.v1.GetWebRequestRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.webrequest.v1.GetWebRequestRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.webrequest.v1.GetWebRequestRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=822,
  serialized_end=877,
)


_GETWEBREQUESTRESPONSE = _descriptor.Descriptor(
  name='GetWebRequestResponse',
  full_name='github.com.metaprov.modelaapi.services.webrequest.v1.GetWebRequestResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.webrequest.v1.GetWebRequestResponse.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yaml', full_name='github.com.metaprov.modelaapi.services.webrequest.v1.GetWebRequestResponse.yaml', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=879,
  serialized_end=996,
)


_DELETEWEBREQUESTREQUEST = _descriptor.Descriptor(
  name='DeleteWebRequestRequest',
  full_name='github.com.metaprov.modelaapi.services.webrequest.v1.DeleteWebRequestRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.webrequest.v1.DeleteWebRequestRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.webrequest.v1.DeleteWebRequestRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=998,
  serialized_end=1056,
)


_DELETEWEBREQUESTRESPONSE = _descriptor.Descriptor(
  name='DeleteWebRequestResponse',
  full_name='github.com.metaprov.modelaapi.services.webrequest.v1.DeleteWebRequestResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1058,
  serialized_end=1084,
)


_RUNWEBREQUESTREQUEST = _descriptor.Descriptor(
  name='RunWebRequestRequest',
  full_name='github.com.metaprov.modelaapi.services.webrequest.v1.RunWebRequestRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.webrequest.v1.RunWebRequestRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1086,
  serialized_end=1188,
)


_RUNWEBREQUESTRESPONSE = _descriptor.Descriptor(
  name='RunWebRequestResponse',
  full_name='github.com.metaprov.modelaapi.services.webrequest.v1.RunWebRequestResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1190,
  serialized_end=1213,
)

_LISTWEBREQUESTSREQUEST_LABELSENTRY.containing_type = _LISTWEBREQUESTSREQUEST
_LISTWEBREQUESTSREQUEST.fields_by_name['labels'].message_type = _LISTWEBREQUESTSREQUEST_LABELSENTRY
_LISTWEBREQUESTSRESPONSE.fields_by_name['items'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._WEBREQUESTLIST
_CREATEWEBREQUESTREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._WEBREQUEST
_UPDATEWEBREQUESTREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._WEBREQUEST
_GETWEBREQUESTRESPONSE.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._WEBREQUEST
_RUNWEBREQUESTREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._WEBREQUEST
DESCRIPTOR.message_types_by_name['ListWebRequestsRequest'] = _LISTWEBREQUESTSREQUEST
DESCRIPTOR.message_types_by_name['ListWebRequestsResponse'] = _LISTWEBREQUESTSRESPONSE
DESCRIPTOR.message_types_by_name['CreateWebRequestResponse'] = _CREATEWEBREQUESTRESPONSE
DESCRIPTOR.message_types_by_name['CreateWebRequestRequest'] = _CREATEWEBREQUESTREQUEST
DESCRIPTOR.message_types_by_name['UpdateWebRequestRequest'] = _UPDATEWEBREQUESTREQUEST
DESCRIPTOR.message_types_by_name['UpdateWebRequestResponse'] = _UPDATEWEBREQUESTRESPONSE
DESCRIPTOR.message_types_by_name['GetWebRequestRequest'] = _GETWEBREQUESTREQUEST
DESCRIPTOR.message_types_by_name['GetWebRequestResponse'] = _GETWEBREQUESTRESPONSE
DESCRIPTOR.message_types_by_name['DeleteWebRequestRequest'] = _DELETEWEBREQUESTREQUEST
DESCRIPTOR.message_types_by_name['DeleteWebRequestResponse'] = _DELETEWEBREQUESTRESPONSE
DESCRIPTOR.message_types_by_name['RunWebRequestRequest'] = _RUNWEBREQUESTREQUEST
DESCRIPTOR.message_types_by_name['RunWebRequestResponse'] = _RUNWEBREQUESTRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ListWebRequestsRequest = _reflection.GeneratedProtocolMessageType('ListWebRequestsRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTWEBREQUESTSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.webrequest.v1.webrequest_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.webrequest.v1.ListWebRequestsRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTWEBREQUESTSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.webrequest.v1.webrequest_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.webrequest.v1.ListWebRequestsRequest)
  })
_sym_db.RegisterMessage(ListWebRequestsRequest)
_sym_db.RegisterMessage(ListWebRequestsRequest.LabelsEntry)

ListWebRequestsResponse = _reflection.GeneratedProtocolMessageType('ListWebRequestsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTWEBREQUESTSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.webrequest.v1.webrequest_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.webrequest.v1.ListWebRequestsResponse)
  })
_sym_db.RegisterMessage(ListWebRequestsResponse)

CreateWebRequestResponse = _reflection.GeneratedProtocolMessageType('CreateWebRequestResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEWEBREQUESTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.webrequest.v1.webrequest_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.webrequest.v1.CreateWebRequestResponse)
  })
_sym_db.RegisterMessage(CreateWebRequestResponse)

CreateWebRequestRequest = _reflection.GeneratedProtocolMessageType('CreateWebRequestRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEWEBREQUESTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.webrequest.v1.webrequest_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.webrequest.v1.CreateWebRequestRequest)
  })
_sym_db.RegisterMessage(CreateWebRequestRequest)

UpdateWebRequestRequest = _reflection.GeneratedProtocolMessageType('UpdateWebRequestRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEWEBREQUESTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.webrequest.v1.webrequest_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.webrequest.v1.UpdateWebRequestRequest)
  })
_sym_db.RegisterMessage(UpdateWebRequestRequest)

UpdateWebRequestResponse = _reflection.GeneratedProtocolMessageType('UpdateWebRequestResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEWEBREQUESTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.webrequest.v1.webrequest_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.webrequest.v1.UpdateWebRequestResponse)
  })
_sym_db.RegisterMessage(UpdateWebRequestResponse)

GetWebRequestRequest = _reflection.GeneratedProtocolMessageType('GetWebRequestRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETWEBREQUESTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.webrequest.v1.webrequest_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.webrequest.v1.GetWebRequestRequest)
  })
_sym_db.RegisterMessage(GetWebRequestRequest)

GetWebRequestResponse = _reflection.GeneratedProtocolMessageType('GetWebRequestResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETWEBREQUESTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.webrequest.v1.webrequest_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.webrequest.v1.GetWebRequestResponse)
  })
_sym_db.RegisterMessage(GetWebRequestResponse)

DeleteWebRequestRequest = _reflection.GeneratedProtocolMessageType('DeleteWebRequestRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEWEBREQUESTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.webrequest.v1.webrequest_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.webrequest.v1.DeleteWebRequestRequest)
  })
_sym_db.RegisterMessage(DeleteWebRequestRequest)

DeleteWebRequestResponse = _reflection.GeneratedProtocolMessageType('DeleteWebRequestResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEWEBREQUESTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.webrequest.v1.webrequest_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.webrequest.v1.DeleteWebRequestResponse)
  })
_sym_db.RegisterMessage(DeleteWebRequestResponse)

RunWebRequestRequest = _reflection.GeneratedProtocolMessageType('RunWebRequestRequest', (_message.Message,), {
  'DESCRIPTOR' : _RUNWEBREQUESTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.webrequest.v1.webrequest_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.webrequest.v1.RunWebRequestRequest)
  })
_sym_db.RegisterMessage(RunWebRequestRequest)

RunWebRequestResponse = _reflection.GeneratedProtocolMessageType('RunWebRequestResponse', (_message.Message,), {
  'DESCRIPTOR' : _RUNWEBREQUESTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.webrequest.v1.webrequest_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.webrequest.v1.RunWebRequestResponse)
  })
_sym_db.RegisterMessage(RunWebRequestResponse)


DESCRIPTOR._options = None
_LISTWEBREQUESTSREQUEST_LABELSENTRY._options = None

_WEBREQUESTSERVICE = _descriptor.ServiceDescriptor(
  name='WebRequestService',
  full_name='github.com.metaprov.modelaapi.services.webrequest.v1.WebRequestService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1216,
  serialized_end=2502,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListWebRequests',
    full_name='github.com.metaprov.modelaapi.services.webrequest.v1.WebRequestService.ListWebRequests',
    index=0,
    containing_service=None,
    input_type=_LISTWEBREQUESTSREQUEST,
    output_type=_LISTWEBREQUESTSRESPONSE,
    serialized_options=b'\202\323\344\223\002\021\022\017/v1/webrequests',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateWebRequest',
    full_name='github.com.metaprov.modelaapi.services.webrequest.v1.WebRequestService.CreateWebRequest',
    index=1,
    containing_service=None,
    input_type=_CREATEWEBREQUESTREQUEST,
    output_type=_CREATEWEBREQUESTRESPONSE,
    serialized_options=b'\202\323\344\223\002\024\"\017/v1/webrequests:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetWebRequest',
    full_name='github.com.metaprov.modelaapi.services.webrequest.v1.WebRequestService.GetWebRequest',
    index=2,
    containing_service=None,
    input_type=_GETWEBREQUESTREQUEST,
    output_type=_GETWEBREQUESTRESPONSE,
    serialized_options=b'\202\323\344\223\002\030\022\026/v1/webrequests/{name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateWebRequest',
    full_name='github.com.metaprov.modelaapi.services.webrequest.v1.WebRequestService.UpdateWebRequest',
    index=3,
    containing_service=None,
    input_type=_UPDATEWEBREQUESTREQUEST,
    output_type=_UPDATEWEBREQUESTRESPONSE,
    serialized_options=b'\202\323\344\223\002/\032*/v1/webrequests/{prediction.metadata.name}:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteWebRequest',
    full_name='github.com.metaprov.modelaapi.services.webrequest.v1.WebRequestService.DeleteWebRequest',
    index=4,
    containing_service=None,
    input_type=_DELETEWEBREQUESTREQUEST,
    output_type=_DELETEWEBREQUESTRESPONSE,
    serialized_options=b'\202\323\344\223\002\030*\026/v1/webrequests/{name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RunWebRequest',
    full_name='github.com.metaprov.modelaapi.services.webrequest.v1.WebRequestService.RunWebRequest',
    index=5,
    containing_service=None,
    input_type=_RUNWEBREQUESTREQUEST,
    output_type=_RUNWEBREQUESTRESPONSE,
    serialized_options=b'\202\323\344\223\002\034\"\032/v1/webrequests/{name}:run',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_WEBREQUESTSERVICE)

DESCRIPTOR.services_by_name['WebRequestService'] = _WEBREQUESTSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/predictiveapp/v1/predictiveapp.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_inference_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='github.com/metaprov/modelaapi/services/predictiveapp/v1/predictiveapp.proto',
  package='github.com.metaprov.modelaapi.services.predictiveapp.v1',
  syntax='proto3',
  serialized_options=b'Z7github.com/metaprov/modelaapi/services/predictiveapp/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nKgithub.com/metaprov/modelaapi/services/predictiveapp/v1/predictiveapp.proto\x12\x37github.com.metaprov.modelaapi.services.predictiveapp.v1\x1a\x1cgoogle/api/annotations.proto\x1aIgithub.com/metaprov/modelaapi/pkg/apis/inference/v1alpha1/generated.proto\"\xdb\x01\n\x19ListPredictiveAppsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12n\n\x06labels\x18\x03 \x03(\x0b\x32^.github.com.metaprov.modelaapi.services.predictiveapp.v1.ListPredictiveAppsRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"y\n\x1aListPredictiveAppsResponse\x12[\n\x05items\x18\x01 \x01(\x0b\x32L.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.PredictiveAppList\"\x1d\n\x1b\x43reatePredictiveAppResponse\"t\n\x1a\x43reatePredictiveAppRequest\x12V\n\x04item\x18\x01 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.PredictiveApp\"t\n\x1aUpdatePredictiveAppRequest\x12V\n\x04item\x18\x01 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.PredictiveApp\"\x1d\n\x1bUpdatePredictiveAppResponse\":\n\x17GetPredictiveAppRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x80\x01\n\x18GetPredictiveAppResponse\x12V\n\x04item\x18\x01 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.PredictiveApp\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"=\n\x1a\x44\x65letePredictiveAppRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x1d\n\x1b\x44\x65letePredictiveAppResponse\"<\n\x19PausePredictiveAppRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x1c\n\x1aPausePredictiveAppResponse\"=\n\x1aResumePredictiveAppRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x1d\n\x1bResumePredictiveAppResponse\"q\n\x17RunPredictiveAppRequest\x12V\n\x04item\x18\x01 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.PredictiveApp\"\x1a\n\x18RunPredictiveAppResponse2\xd5\x0c\n\x14PredictiveAppService\x12\xd6\x01\n\x12ListPredictiveApps\x12R.github.com.metaprov.modelaapi.services.predictiveapp.v1.ListPredictiveAppsRequest\x1aS.github.com.metaprov.modelaapi.services.predictiveapp.v1.ListPredictiveAppsResponse\"\x17\x82\xd3\xe4\x93\x02\x11\x12\x0f/v1/webeequests\x12\xdc\x01\n\x13\x43reatePredictiveApp\x12S.github.com.metaprov.modelaapi.services.predictiveapp.v1.CreatePredictiveAppRequest\x1aT.github.com.metaprov.modelaapi.services.predictiveapp.v1.CreatePredictiveAppResponse\"\x1a\x82\xd3\xe4\x93\x02\x14\"\x0f/v1/webeequests:\x01*\x12\xd7\x01\n\x10GetPredictiveApp\x12P.github.com.metaprov.modelaapi.services.predictiveapp.v1.GetPredictiveAppRequest\x1aQ.github.com.metaprov.modelaapi.services.predictiveapp.v1.GetPredictiveAppResponse\"\x1e\x82\xd3\xe4\x93\x02\x18\x12\x16/v1/webeequests/{name}\x12\xf7\x01\n\x13UpdatePredictiveApp\x12S.github.com.metaprov.modelaapi.services.predictiveapp.v1.UpdatePredictiveAppRequest\x1aT.github.com.metaprov.modelaapi.services.predictiveapp.v1.UpdatePredictiveAppResponse\"5\x82\xd3\xe4\x93\x02/\x1a*/v1/webeequests/{webeequest.metadata.name}:\x01*\x12\xe0\x01\n\x13\x44\x65letePredictiveApp\x12S.github.com.metaprov.modelaapi.services.predictiveapp.v1.DeletePredictiveAppRequest\x1aT.github.com.metaprov.modelaapi.services.predictiveapp.v1.DeletePredictiveAppResponse\"\x1e\x82\xd3\xe4\x93\x02\x18*\x16/v1/webeequests/{name}\x12\xe3\x01\n\x12PausePredictiveApp\x12R.github.com.metaprov.modelaapi.services.predictiveapp.v1.PausePredictiveAppRequest\x1aS.github.com.metaprov.modelaapi.services.predictiveapp.v1.PausePredictiveAppResponse\"$\x82\xd3\xe4\x93\x02\x1e\"\x1c/v1/webeequests/{name}:pause\x12\xe7\x01\n\x13ResumePredictiveApp\x12S.github.com.metaprov.modelaapi.services.predictiveapp.v1.ResumePredictiveAppRequest\x1aT.github.com.metaprov.modelaapi.services.predictiveapp.v1.ResumePredictiveAppResponse\"%\x82\xd3\xe4\x93\x02\x1f\"\x1d/v1/webeequests/{name}:resumeB9Z7github.com/metaprov/modelaapi/services/predictiveapp/v1b\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_inference_dot_v1alpha1_dot_generated__pb2.DESCRIPTOR,])




_LISTPREDICTIVEAPPSREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='github.com.metaprov.modelaapi.services.predictiveapp.v1.ListPredictiveAppsRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.predictiveapp.v1.ListPredictiveAppsRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.predictiveapp.v1.ListPredictiveAppsRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=416,
  serialized_end=461,
)

_LISTPREDICTIVEAPPSREQUEST = _descriptor.Descriptor(
  name='ListPredictiveAppsRequest',
  full_name='github.com.metaprov.modelaapi.services.predictiveapp.v1.ListPredictiveAppsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.predictiveapp.v1.ListPredictiveAppsRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.predictiveapp.v1.ListPredictiveAppsRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='github.com.metaprov.modelaapi.services.predictiveapp.v1.ListPredictiveAppsRequest.labels', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTPREDICTIVEAPPSREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=242,
  serialized_end=461,
)


_LISTPREDICTIVEAPPSRESPONSE = _descriptor.Descriptor(
  name='ListPredictiveAppsResponse',
  full_name='github.com.metaprov.modelaapi.services.predictiveapp.v1.ListPredictiveAppsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.predictiveapp.v1.ListPredictiveAppsResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=463,
  serialized_end=584,
)


_CREATEPREDICTIVEAPPRESPONSE = _descriptor.Descriptor(
  name='CreatePredictiveAppResponse',
  full_name='github.com.metaprov.modelaapi.services.predictiveapp.v1.CreatePredictiveAppResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=586,
  serialized_end=615,
)


_CREATEPREDICTIVEAPPREQUEST = _descriptor.Descriptor(
  name='CreatePredictiveAppRequest',
  full_name='github.com.metaprov.modelaapi.services.predictiveapp.v1.CreatePredictiveAppRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.predictiveapp.v1.CreatePredictiveAppRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=617,
  serialized_end=733,
)


_UPDATEPREDICTIVEAPPREQUEST = _descriptor.Descriptor(
  name='UpdatePredictiveAppRequest',
  full_name='github.com.metaprov.modelaapi.services.predictiveapp.v1.UpdatePredictiveAppRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.predictiveapp.v1.UpdatePredictiveAppRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=735,
  serialized_end=851,
)


_UPDATEPREDICTIVEAPPRESPONSE = _descriptor.Descriptor(
  name='UpdatePredictiveAppResponse',
  full_name='github.com.metaprov.modelaapi.services.predictiveapp.v1.UpdatePredictiveAppResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=853,
  serialized_end=882,
)


_GETPREDICTIVEAPPREQUEST = _descriptor.Descriptor(
  name='GetPredictiveAppRequest',
  full_name='github.com.metaprov.modelaapi.services.predictiveapp.v1.GetPredictiveAppRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.predictiveapp.v1.GetPredictiveAppRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.predictiveapp.v1.GetPredictiveAppRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=884,
  serialized_end=942,
)


_GETPREDICTIVEAPPRESPONSE = _descriptor.Descriptor(
  name='GetPredictiveAppResponse',
  full_name='github.com.metaprov.modelaapi.services.predictiveapp.v1.GetPredictiveAppResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.predictiveapp.v1.GetPredictiveAppResponse.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yaml', full_name='github.com.metaprov.modelaapi.services.predictiveapp.v1.GetPredictiveAppResponse.yaml', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=945,
  serialized_end=1073,
)


_DELETEPREDICTIVEAPPREQUEST = _descriptor.Descriptor(
  name='DeletePredictiveAppRequest',
  full_name='github.com.metaprov.modelaapi.services.predictiveapp.v1.DeletePredictiveAppRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.predictiveapp.v1.DeletePredictiveAppRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.predictiveapp.v1.DeletePredictiveAppRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1075,
  serialized_end=1136,
)


_DELETEPREDICTIVEAPPRESPONSE = _descriptor.Descriptor(
  name='DeletePredictiveAppResponse',
  full_name='github.com.metaprov.modelaapi.services.predictiveapp.v1.DeletePredictiveAppResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1138,
  serialized_end=1167,
)


_PAUSEPREDICTIVEAPPREQUEST = _descriptor.Descriptor(
  name='PausePredictiveAppRequest',
  full_name='github.com.metaprov.modelaapi.services.predictiveapp.v1.PausePredictiveAppRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.predictiveapp.v1.PausePredictiveAppRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.predictiveapp.v1.PausePredictiveAppRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1169,
  serialized_end=1229,
)


_PAUSEPREDICTIVEAPPRESPONSE = _descriptor.Descriptor(
  name='PausePredictiveAppResponse',
  full_name='github.com.metaprov.modelaapi.services.predictiveapp.v1.PausePredictiveAppResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1231,
  serialized_end=1259,
)


_RESUMEPREDICTIVEAPPREQUEST = _descriptor.Descriptor(
  name='ResumePredictiveAppRequest',
  full_name='github.com.metaprov.modelaapi.services.predictiveapp.v1.ResumePredictiveAppRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.predictiveapp.v1.ResumePredictiveAppRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.predictiveapp.v1.ResumePredictiveAppRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1261,
  serialized_end=1322,
)


_RESUMEPREDICTIVEAPPRESPONSE = _descriptor.Descriptor(
  name='ResumePredictiveAppResponse',
  full_name='github.com.metaprov.modelaapi.services.predictiveapp.v1.ResumePredictiveAppResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1324,
  serialized_end=1353,
)


_RUNPREDICTIVEAPPREQUEST = _descriptor.Descriptor(
  name='RunPredictiveAppRequest',
  full_name='github.com.metaprov.modelaapi.services.predictiveapp.v1.RunPredictiveAppRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.predictiveapp.v1.RunPredictiveAppRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1355,
  serialized_end=1468,
)


_RUNPREDICTIVEAPPRESPONSE = _descriptor.Descriptor(
  name='RunPredictiveAppResponse',
  full_name='github.com.metaprov.modelaapi.services.predictiveapp.v1.RunPredictiveAppResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1470,
  serialized_end=1496,
)

_LISTPREDICTIVEAPPSREQUEST_LABELSENTRY.containing_type = _LISTPREDICTIVEAPPSREQUEST
_LISTPREDICTIVEAPPSREQUEST.fields_by_name['labels'].message_type = _LISTPREDICTIVEAPPSREQUEST_LABELSENTRY
_LISTPREDICTIVEAPPSRESPONSE.fields_by_name['items'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_inference_dot_v1alpha1_dot_generated__pb2._PREDICTIVEAPPLIST
_CREATEPREDICTIVEAPPREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_inference_dot_v1alpha1_dot_generated__pb2._PREDICTIVEAPP
_UPDATEPREDICTIVEAPPREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_inference_dot_v1alpha1_dot_generated__pb2._PREDICTIVEAPP
_GETPREDICTIVEAPPRESPONSE.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_inference_dot_v1alpha1_dot_generated__pb2._PREDICTIVEAPP
_RUNPREDICTIVEAPPREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_inference_dot_v1alpha1_dot_generated__pb2._PREDICTIVEAPP
DESCRIPTOR.message_types_by_name['ListPredictiveAppsRequest'] = _LISTPREDICTIVEAPPSREQUEST
DESCRIPTOR.message_types_by_name['ListPredictiveAppsResponse'] = _LISTPREDICTIVEAPPSRESPONSE
DESCRIPTOR.message_types_by_name['CreatePredictiveAppResponse'] = _CREATEPREDICTIVEAPPRESPONSE
DESCRIPTOR.message_types_by_name['CreatePredictiveAppRequest'] = _CREATEPREDICTIVEAPPREQUEST
DESCRIPTOR.message_types_by_name['UpdatePredictiveAppRequest'] = _UPDATEPREDICTIVEAPPREQUEST
DESCRIPTOR.message_types_by_name['UpdatePredictiveAppResponse'] = _UPDATEPREDICTIVEAPPRESPONSE
DESCRIPTOR.message_types_by_name['GetPredictiveAppRequest'] = _GETPREDICTIVEAPPREQUEST
DESCRIPTOR.message_types_by_name['GetPredictiveAppResponse'] = _GETPREDICTIVEAPPRESPONSE
DESCRIPTOR.message_types_by_name['DeletePredictiveAppRequest'] = _DELETEPREDICTIVEAPPREQUEST
DESCRIPTOR.message_types_by_name['DeletePredictiveAppResponse'] = _DELETEPREDICTIVEAPPRESPONSE
DESCRIPTOR.message_types_by_name['PausePredictiveAppRequest'] = _PAUSEPREDICTIVEAPPREQUEST
DESCRIPTOR.message_types_by_name['PausePredictiveAppResponse'] = _PAUSEPREDICTIVEAPPRESPONSE
DESCRIPTOR.message_types_by_name['ResumePredictiveAppRequest'] = _RESUMEPREDICTIVEAPPREQUEST
DESCRIPTOR.message_types_by_name['ResumePredictiveAppResponse'] = _RESUMEPREDICTIVEAPPRESPONSE
DESCRIPTOR.message_types_by_name['RunPredictiveAppRequest'] = _RUNPREDICTIVEAPPREQUEST
DESCRIPTOR.message_types_by_name['RunPredictiveAppResponse'] = _RUNPREDICTIVEAPPRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ListPredictiveAppsRequest = _reflection.GeneratedProtocolMessageType('ListPredictiveAppsRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTPREDICTIVEAPPSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.predictiveapp.v1.predictiveapp_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.predictiveapp.v1.ListPredictiveAppsRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTPREDICTIVEAPPSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.predictiveapp.v1.predictiveapp_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.predictiveapp.v1.ListPredictiveAppsRequest)
  })
_sym_db.RegisterMessage(ListPredictiveAppsRequest)
_sym_db.RegisterMessage(ListPredictiveAppsRequest.LabelsEntry)

ListPredictiveAppsResponse = _reflection.GeneratedProtocolMessageType('ListPredictiveAppsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTPREDICTIVEAPPSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.predictiveapp.v1.predictiveapp_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.predictiveapp.v1.ListPredictiveAppsResponse)
  })
_sym_db.RegisterMessage(ListPredictiveAppsResponse)

CreatePredictiveAppResponse = _reflection.GeneratedProtocolMessageType('CreatePredictiveAppResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPREDICTIVEAPPRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.predictiveapp.v1.predictiveapp_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.predictiveapp.v1.CreatePredictiveAppResponse)
  })
_sym_db.RegisterMessage(CreatePredictiveAppResponse)

CreatePredictiveAppRequest = _reflection.GeneratedProtocolMessageType('CreatePredictiveAppRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPREDICTIVEAPPREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.predictiveapp.v1.predictiveapp_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.predictiveapp.v1.CreatePredictiveAppRequest)
  })
_sym_db.RegisterMessage(CreatePredictiveAppRequest)

UpdatePredictiveAppRequest = _reflection.GeneratedProtocolMessageType('UpdatePredictiveAppRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEPREDICTIVEAPPREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.predictiveapp.v1.predictiveapp_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.predictiveapp.v1.UpdatePredictiveAppRequest)
  })
_sym_db.RegisterMessage(UpdatePredictiveAppRequest)

UpdatePredictiveAppResponse = _reflection.GeneratedProtocolMessageType('UpdatePredictiveAppResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEPREDICTIVEAPPRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.predictiveapp.v1.predictiveapp_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.predictiveapp.v1.UpdatePredictiveAppResponse)
  })
_sym_db.RegisterMessage(UpdatePredictiveAppResponse)

GetPredictiveAppRequest = _reflection.GeneratedProtocolMessageType('GetPredictiveAppRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPREDICTIVEAPPREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.predictiveapp.v1.predictiveapp_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.predictiveapp.v1.GetPredictiveAppRequest)
  })
_sym_db.RegisterMessage(GetPredictiveAppRequest)

GetPredictiveAppResponse = _reflection.GeneratedProtocolMessageType('GetPredictiveAppResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETPREDICTIVEAPPRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.predictiveapp.v1.predictiveapp_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.predictiveapp.v1.GetPredictiveAppResponse)
  })
_sym_db.RegisterMessage(GetPredictiveAppResponse)

DeletePredictiveAppRequest = _reflection.GeneratedProtocolMessageType('DeletePredictiveAppRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEPREDICTIVEAPPREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.predictiveapp.v1.predictiveapp_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.predictiveapp.v1.DeletePredictiveAppRequest)
  })
_sym_db.RegisterMessage(DeletePredictiveAppRequest)

DeletePredictiveAppResponse = _reflection.GeneratedProtocolMessageType('DeletePredictiveAppResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEPREDICTIVEAPPRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.predictiveapp.v1.predictiveapp_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.predictiveapp.v1.DeletePredictiveAppResponse)
  })
_sym_db.RegisterMessage(DeletePredictiveAppResponse)

PausePredictiveAppRequest = _reflection.GeneratedProtocolMessageType('PausePredictiveAppRequest', (_message.Message,), {
  'DESCRIPTOR' : _PAUSEPREDICTIVEAPPREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.predictiveapp.v1.predictiveapp_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.predictiveapp.v1.PausePredictiveAppRequest)
  })
_sym_db.RegisterMessage(PausePredictiveAppRequest)

PausePredictiveAppResponse = _reflection.GeneratedProtocolMessageType('PausePredictiveAppResponse', (_message.Message,), {
  'DESCRIPTOR' : _PAUSEPREDICTIVEAPPRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.predictiveapp.v1.predictiveapp_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.predictiveapp.v1.PausePredictiveAppResponse)
  })
_sym_db.RegisterMessage(PausePredictiveAppResponse)

ResumePredictiveAppRequest = _reflection.GeneratedProtocolMessageType('ResumePredictiveAppRequest', (_message.Message,), {
  'DESCRIPTOR' : _RESUMEPREDICTIVEAPPREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.predictiveapp.v1.predictiveapp_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.predictiveapp.v1.ResumePredictiveAppRequest)
  })
_sym_db.RegisterMessage(ResumePredictiveAppRequest)

ResumePredictiveAppResponse = _reflection.GeneratedProtocolMessageType('ResumePredictiveAppResponse', (_message.Message,), {
  'DESCRIPTOR' : _RESUMEPREDICTIVEAPPRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.predictiveapp.v1.predictiveapp_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.predictiveapp.v1.ResumePredictiveAppResponse)
  })
_sym_db.RegisterMessage(ResumePredictiveAppResponse)

RunPredictiveAppRequest = _reflection.GeneratedProtocolMessageType('RunPredictiveAppRequest', (_message.Message,), {
  'DESCRIPTOR' : _RUNPREDICTIVEAPPREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.predictiveapp.v1.predictiveapp_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.predictiveapp.v1.RunPredictiveAppRequest)
  })
_sym_db.RegisterMessage(RunPredictiveAppRequest)

RunPredictiveAppResponse = _reflection.GeneratedProtocolMessageType('RunPredictiveAppResponse', (_message.Message,), {
  'DESCRIPTOR' : _RUNPREDICTIVEAPPRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.predictiveapp.v1.predictiveapp_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.predictiveapp.v1.RunPredictiveAppResponse)
  })
_sym_db.RegisterMessage(RunPredictiveAppResponse)


DESCRIPTOR._options = None
_LISTPREDICTIVEAPPSREQUEST_LABELSENTRY._options = None

_PREDICTIVEAPPSERVICE = _descriptor.ServiceDescriptor(
  name='PredictiveAppService',
  full_name='github.com.metaprov.modelaapi.services.predictiveapp.v1.PredictiveAppService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1499,
  serialized_end=3120,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListPredictiveApps',
    full_name='github.com.metaprov.modelaapi.services.predictiveapp.v1.PredictiveAppService.ListPredictiveApps',
    index=0,
    containing_service=None,
    input_type=_LISTPREDICTIVEAPPSREQUEST,
    output_type=_LISTPREDICTIVEAPPSRESPONSE,
    serialized_options=b'\202\323\344\223\002\021\022\017/v1/webeequests',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreatePredictiveApp',
    full_name='github.com.metaprov.modelaapi.services.predictiveapp.v1.PredictiveAppService.CreatePredictiveApp',
    index=1,
    containing_service=None,
    input_type=_CREATEPREDICTIVEAPPREQUEST,
    output_type=_CREATEPREDICTIVEAPPRESPONSE,
    serialized_options=b'\202\323\344\223\002\024\"\017/v1/webeequests:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetPredictiveApp',
    full_name='github.com.metaprov.modelaapi.services.predictiveapp.v1.PredictiveAppService.GetPredictiveApp',
    index=2,
    containing_service=None,
    input_type=_GETPREDICTIVEAPPREQUEST,
    output_type=_GETPREDICTIVEAPPRESPONSE,
    serialized_options=b'\202\323\344\223\002\030\022\026/v1/webeequests/{name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdatePredictiveApp',
    full_name='github.com.metaprov.modelaapi.services.predictiveapp.v1.PredictiveAppService.UpdatePredictiveApp',
    index=3,
    containing_service=None,
    input_type=_UPDATEPREDICTIVEAPPREQUEST,
    output_type=_UPDATEPREDICTIVEAPPRESPONSE,
    serialized_options=b'\202\323\344\223\002/\032*/v1/webeequests/{webeequest.metadata.name}:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeletePredictiveApp',
    full_name='github.com.metaprov.modelaapi.services.predictiveapp.v1.PredictiveAppService.DeletePredictiveApp',
    index=4,
    containing_service=None,
    input_type=_DELETEPREDICTIVEAPPREQUEST,
    output_type=_DELETEPREDICTIVEAPPRESPONSE,
    serialized_options=b'\202\323\344\223\002\030*\026/v1/webeequests/{name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='PausePredictiveApp',
    full_name='github.com.metaprov.modelaapi.services.predictiveapp.v1.PredictiveAppService.PausePredictiveApp',
    index=5,
    containing_service=None,
    input_type=_PAUSEPREDICTIVEAPPREQUEST,
    output_type=_PAUSEPREDICTIVEAPPRESPONSE,
    serialized_options=b'\202\323\344\223\002\036\"\034/v1/webeequests/{name}:pause',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ResumePredictiveApp',
    full_name='github.com.metaprov.modelaapi.services.predictiveapp.v1.PredictiveAppService.ResumePredictiveApp',
    index=6,
    containing_service=None,
    input_type=_RESUMEPREDICTIVEAPPREQUEST,
    output_type=_RESUMEPREDICTIVEAPPRESPONSE,
    serialized_options=b'\202\323\344\223\002\037\"\035/v1/webeequests/{name}:resume',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_PREDICTIVEAPPSERVICE)

DESCRIPTOR.services_by_name['PredictiveAppService'] = _PREDICTIVEAPPSERVICE

# @@protoc_insertion_point(module_scope)
